@@ -20,12 +20,18 @@ from cakework import cakework_pb2
 from cakework import cakework_pb2_grpc
 import json
 import importlib
-import os
+# import os
 
 class Cakework(cakework_pb2_grpc.CakeworkServicer):
     def __init__(self):
-        self.module = os.environ['MODULE']
-        self.activity = os.environ['ACTIVITY']
+        with open('cakework.json') as infile:
+            conf = json.load(infile)
+        # self.module = os.environ['MODULE']
+        self.module = conf['module']
+        # self.activity = os.environ['ACTIVITY']
+        self.activity = conf['activity']
+        print("module: " + self.module)
+        print("activity: " + self.activity)
         print("Running module: " + self.module + ", activity: " + self.activity) # TODO do proper logging
 
     def RunActivity(self, request, context):
@@ -35,7 +41,7 @@ class Cakework(cakework_pb2_grpc.CakeworkServicer):
         # TODO do something with the context
         parameters = json.loads(request.parameters)
         activity = getattr(module, self.activity)
-        res = activity()
+        res = activity(**parameters)
         return cakework_pb2.Reply(result=json.dumps(res))
 
 def serve():
